==> foundation-0.0.45.tgz: package/Default/Tools/Data/WorldData/ChunkDataTool.js <==
//objects
import { WorldRegister } from "../../../../Data/World/WorldRegister.js";
import { EncodedPositionDataTool } from "../../Classes/DataToolBase.js";
import { WorldSpaces } from "@divinevoxel/core/Data/World/WorldSpaces.js";
import { Chunk } from "../../../../Data/World/Classes/Chunk.js";
export class ChunkDataTool extends EncodedPositionDataTool {
    tags = Chunk.Tags;
    constructor() {
        super();
    }
    _chunk;
    loadIn() {
        WorldSpaces.chunk.updateLoaction(this.location);
        const chunk = WorldRegister.chunk.get(this.location);
        if (!chunk)
            return false;
        this.tags.setBuffer(chunk.chunkState);
        this._c = chunk.chunkState;
        this._chunk = chunk;
        return true;
    }
    setChunk(chunk) {
        this.tags.setBuffer(chunk.chunkState);
        this._c = chunk.chunkState;
        this._chunk = chunk;
        return this;
    }
    segments = {
        id: {
            get: (index) => {
                return this._chunk.ids[index];
            },
            set: (index, value) => {
                return (this._chunk.ids[index] = value);
            },
        },
        light: {
            get: (index) => {
                return this._chunk.light[index];
            },
            set: (index, value) => {
                return (this._chunk.light[index] = value);
            },
        },
        state: {
            get: (index) => {
                return this._chunk.state[index];
            },
            set: (index, value) => {
                return (this._chunk.state[index] = value);
            },
        },
        secondaryId: {
            get: (index) => {
                return this._chunk.secondaryIds[index];
            },
            set: (index, value) => {
                return (this._chunk.secondaryIds[index] = value);
            },
        },
    };
}

==> foundation-0.0.52.tgz: package/Default/Tools/Data/WorldData/ChunkDataTool.js <==
//objects
import { EncodedPositionDataTool } from "../../Classes/DataToolBase.js";
import { WorldRegister } from "../../../../Data/World/WorldRegister.js";
import { WorldSpaces } from "@divinevoxel/core/Data/World/WorldSpaces.js";
import { Chunk } from "../../../../Data/World/Classes/Chunk.js";
export class ChunkDataTool extends EncodedPositionDataTool {
    tags = Chunk.Tags;
    constructor() {
        super();
    }
    _chunk;
    loadIn() {
        WorldSpaces.chunk.updateLoaction(this.location);
        const chunk = WorldRegister.instance.chunk.get(this.location);
        if (!chunk)
            return false;
        this.tags.setBuffer(chunk.chunkState);
        this._c = chunk.chunkState;
        this._chunk = chunk;
        return true;
    }
    setChunk(chunk) {
        this.tags.setBuffer(chunk.chunkState);
        this._c = chunk.chunkState;
        this._chunk = chunk;
        return this;
    }
    segments = {
        id: {
            get: (index) => {
                return this._chunk.ids[index];
            },
            set: (index, value) => {
                return (this._chunk.ids[index] = value);
            },
        },
        light: {
            get: (index) => {
                return this._chunk.light[index];
            },
            set: (index, value) => {
                return (this._chunk.light[index] = value);
            },
        },
        state: {
            get: (index) => {
                return this._chunk.state[index];
            },
            set: (index, value) => {
                return (this._chunk.state[index] = value);
            },
        },
        secondaryId: {
            get: (index) => {
                return this._chunk.secondaryIds[index];
            },
            set: (index, value) => {
                return (this._chunk.secondaryIds[index] = value);
            },
        },
    };
}
